@@ -13,7 +13,7 @@
 	{
 		if(intercrossingSingleLociHaplotypeProbabilities == NULL || errorProb != errorProb || errorProb != 0)
 		{
-			throw std::runtime_error("Internal error");
+			THROWINTERNAL();
 		}
 		//Compute forward probabilities
 		double sum = 0;
@@ -222,7 +222,7 @@
 	{
 		if(intercrossingSingleLociHaplotypeProbabilities == NULL || errorProb != errorProb || errorProb <= 0 || errorProb >= 1)
 		{
-			throw std::runtime_error("Internal error");
+			THROWINTERNAL();
 		}
 		//Compute forward probabilities
 		double sum = 0;
