@@ -1,3 +1,4 @@
+#include "throwInternal.h"
 #include "probabilities16.h"
 #include <cmath>
 #include <stdexcept>
@@ -311,7 +312,7 @@ template<> void genotypeProbabilitiesWithIntercross<16, false>(std::array<double
 #ifdef INTERNAL_CHECKS
 	double sum = 0;
 	for(int i = 0; i < 95; i++) sum += prob[i];
-	if(fabs(sum - 1) > 1e-6) throw std::runtime_error("Internal error");
+	if(fabs(sum - 1) > 1e-6) THROWINTERNAL();
 #endif
 	//This is because we combined some states (see mathematica code)
 	prob[0] /= 16;
